from PySide6.QtWidgets import QDialog, QVBoxLayout, QTableWidget, QTableWidgetItem, QPushButton, QHeaderView

class PreviewDialog(QDialog):
    def __init__(self, books, parent=None):
        super().__init__(parent)

        self.setWindowTitle("Preview Books to Import")
        self.setLayout(QVBoxLayout())
        self.setMinimumWidth(500)

        # Table to display books
        table = QTableWidget(self)
        table.setRowCount(len(books))
        table.setColumnCount(4)
        table.setHorizontalHeaderLabels(["Title", "Author", "Year", "ISBN"])

        for row, book in enumerate(books):
            table.setItem(row, 0, QTableWidgetItem(book.title))
            table.setItem(row, 1, QTableWidgetItem(f"{book.author.first_name} {book.author.last_name}"))
            table.setItem(row, 2, QTableWidgetItem(book.year_published))
            table.setItem(row, 3, QTableWidgetItem(book.isbn))

        header = table.horizontalHeader()
        header.setSectionResizeMode(QHeaderView.Stretch)

        self.layout().addWidget(table)

        # Add buttons
        self.confirm_button = QPushButton("Confirm", self)
        self.cancel_button = QPushButton("Cancel", self)
        self.confirm_button.clicked.connect(self.accept)
        self.cancel_button.clicked.connect(self.reject)
        self.layout().addWidget(self.confirm_button)
        self.layout().addWidget(self.cancel_button)
